@@ -1,5 +1,5 @@
 # Definition of the version number
-try:  # pragma: no cover
+try:
     from ._utils import _sh
 except:  # pragma: no cover
     _sh = None
@@ -8,7 +8,7 @@ from subprocess import STDOUT
 __all__ = ["__version__"]
 
 # major, minor, patch, -extra
-version_info = 4, 7, 4
+version_info = 4, 11, 1
 
 # Nice string for the version
 __version__ = '.'.join(map(str, version_info))
