@@ -382,9 +382,9 @@ def test_max_interval():
     total = 100
     bigstep = 10
     smallstep = 5
-    timer = DiscreteTimer()
 
     # Test without maxinterval
+    timer = DiscreteTimer()
     with closing(StringIO()) as our_file:
         with closing(StringIO()) as our_file2:
             # with maxinterval but higher than loop sleep time
@@ -417,6 +417,7 @@ def test_max_interval():
         assert "25%" not in our_file.read()
 
     # Test with maxinterval effect
+    timer = DiscreteTimer()
     with closing(StringIO()) as our_file:
         with tqdm(total=total, file=our_file, miniters=None, mininterval=0,
                   smoothing=1, maxinterval=1e-4) as t:
@@ -433,6 +434,7 @@ def test_max_interval():
             assert "25%" in our_file.read()
 
     # Test iteration based tqdm with maxinterval effect
+    timer = DiscreteTimer()
     with closing(StringIO()) as our_file:
         with tqdm(_range(total), file=our_file, miniters=None,
                   mininterval=1e-5, smoothing=1, maxinterval=1e-4) as t2:
@@ -448,6 +450,69 @@ def test_max_interval():
         our_file.seek(0)
         assert "15%" in our_file.read()
 
+    # Test different behavior with and without mininterval
+    timer = DiscreteTimer()
+    total = 1000
+    mininterval = 0.1
+    maxinterval = 10
+    with closing(StringIO()) as our_file:
+        with tqdm(total=total, file=our_file, miniters=None, smoothing=1,
+                  mininterval=mininterval, maxinterval=maxinterval) as tm1:
+            with tqdm(total=total, file=our_file, miniters=None, smoothing=1,
+                      mininterval=0, maxinterval=maxinterval) as tm2:
+
+                cpu_timify(tm1, timer)
+                cpu_timify(tm2, timer)
+
+                # Fast iterations, check if dynamic_miniters triggers
+                timer.sleep(mininterval)  # to force update for t1
+                tm1.update(total/2)
+                tm2.update(total/2)
+                assert int(tm1.miniters) == tm2.miniters == total/2
+
+                # Slow iterations, check different miniters if mininterval
+                timer.sleep(maxinterval*2)
+                tm1.update(total/2)
+                tm2.update(total/2)
+                res = [tm1.miniters, tm2.miniters]
+                assert res == [
+                               (total/2)*mininterval/(maxinterval*2),
+                               (total/2)*maxinterval/(maxinterval*2)
+                               ]
+
+    # Same with iterable based tqdm
+    timer1 = DiscreteTimer()  # need 2 timers for each bar because zip not work
+    timer2 = DiscreteTimer()
+    total = 100
+    mininterval = 0.1
+    maxinterval = 10
+    with closing(StringIO()) as our_file:
+        t1 = tqdm(_range(total), file=our_file, miniters=None, smoothing=1,
+                  mininterval=mininterval, maxinterval=maxinterval)
+        t2 = tqdm(_range(total), file=our_file, miniters=None, smoothing=1,
+                  mininterval=0, maxinterval=maxinterval)
+
+        cpu_timify(t1, timer1)
+        cpu_timify(t2, timer2)
+
+        for i in t1:
+            if i == ((total/2)-2):
+                timer1.sleep(mininterval)
+            if i == (total-1):
+                timer1.sleep(maxinterval*2)
+
+        for i in t2:
+            if i == ((total/2)-2):
+                timer2.sleep(mininterval)
+            if i == (total-1):
+                timer2.sleep(maxinterval*2)
+
+        assert t1.miniters == 0.255
+        assert t2.miniters == 0.5
+
+        t1.close()
+        t2.close()
+
 
 @with_setup(pretest, posttest)
 def test_min_iters():
@@ -494,12 +559,40 @@ def test_dynamic_min_iters():
     assert '60%' not in out
     assert '70%' in out
 
+    # Check with smoothing=0, miniters should be set to max update seen so far
     with closing(StringIO()) as our_file:
-        t = tqdm(_range(10), file=our_file, miniters=None, mininterval=None)
+        total = 10
+        t = tqdm(total=total, file=our_file, miniters=None, mininterval=0,
+                 smoothing=0)
+
+        t.update()
+        t.update(2)
+        t.update(5)  # this should be stored as miniters
+        t.update(1)
+
+        our_file.seek(0)
+        out = our_file.read()
+        assert t.dynamic_miniters and not t.smoothing
+        assert t.miniters == 5
+        t.close()
+
+    # Check iterable based tqdm
+    with closing(StringIO()) as our_file:
+        t = tqdm(_range(10), file=our_file, miniters=None, mininterval=None,
+                 smoothing=0.5)
         for _ in t:
             pass
         assert t.dynamic_miniters
 
+    # No smoothing
+    with closing(StringIO()) as our_file:
+        t = tqdm(_range(10), file=our_file, miniters=None, mininterval=None,
+                 smoothing=0)
+        for _ in t:
+            pass
+        assert t.dynamic_miniters
+
+    # No dynamic_miniters (miniters is fixed manually)
     with closing(StringIO()) as our_file:
         t = tqdm(_range(10), file=our_file, miniters=1, mininterval=None)
         for _ in t:
@@ -1416,3 +1509,43 @@ def test_monitoring_thread():
                     sleep(0.000001)
                 assert t1.miniters == 1  # check that monitor corrected miniters
                 assert t2.miniters == 500  # check that t2 was not adjusted
+
+
+@with_setup(pretest, posttest)
+def test_postfix():
+    """Test postfix"""
+    postfix = {'float': 0.321034, 'gen': 543, 'str': 'h', 'lst': [2]}
+    postfix_order = (('w', 'w'), ('a', 0))  # no need for a OrderedDict, set is OK
+    expected = ['float=0.321', 'gen=543', 'lst=[2]', 'str=h']
+    expected_order = ['w=w', 'a=0', 'float=0.321', 'gen=543', 'lst=[2]', 'str=h']
+
+    # Test postfix set at init
+    with closing(StringIO()) as our_file:
+        with tqdm(total=10, file=our_file, desc='pos0 bar',
+                  bar_format='{r_bar}', postfix=postfix) as t1:
+            t1.refresh()
+            out = our_file.getvalue()
+
+    # Test postfix set after init
+    with closing(StringIO()) as our_file:
+        with trange(10, file=our_file, desc='pos1 bar',
+                    bar_format='{r_bar}', postfix=None) as t2:
+            t2.set_postfix(**postfix)
+            t2.refresh()
+            out2 = our_file.getvalue()
+
+    # Order of items in dict may change, so need a loop to check per item
+    for res in expected:
+        assert res in out
+        assert res in out2
+
+    # Test postfix set after init and with ordered dict
+    with closing(StringIO()) as our_file:
+        with trange(10, file=our_file, desc='pos2 bar',
+                    bar_format='{r_bar}', postfix=None) as t3:
+            t3.set_postfix(postfix_order, **postfix)
+            t3.refresh()
+            out3 = our_file.getvalue()
+
+    out3 = out3[1:-1].split(', ')[3:]
+    assert out3 == expected_order
